==> purepng-0.1.0.zip: purepng-0.1.0/man/conf.py <==
# $URL$
# $Rev$

# PyPNG documentation build configuration file, created by
# sphinx-quickstart on Mon Mar 16 13:12:26 2009.
# Then brutally hacked down by drj.
# See http://sphinx.pocoo.org/config.html

import sys, os

# So that local modules get picked up, and picked up first.
sys.path.insert(0, os.path.abspath('../code/png'))
# So that setup.py can be picked up and used for its conf member
sys.path.insert(0, os.path.abspath('..'))

# Expecting to find ../setup.py
from setup import conf

# General configuration
# ---------------------

extensions = ['sphinx.ext.autodoc', 'sphinx.ext.intersphinx']
intersphinx_mapping = {'python': ('https://docs.python.org/2.7', None)}
templates_path = []
source_suffix = '.rst'
master_doc = 'index'
project = u'PurePNG'
copyright = u'2014, ' + conf['author']
release = conf['version']
version = release[:release.rfind('.')]
language = 'en'
today_fmt = '%Y-%m-%d'
exclude_trees = ['build']


# Options for HTML output
# -----------------------

html_static_path = []
html_last_updated_fmt = '%Y-%m-%dT%H:%M:%S'
htmlhelp_basename = 'PurePNGdoc'


# Options for LaTeX output
# ------------------------

# The paper size ('letter' or 'a4').
latex_paper_size = 'a4'

# The font size ('10pt', '11pt' or '12pt').
#latex_font_size = '10pt'

#Grouping the document tree into LaTeX files. List of tuples
#(source start file, target name, title, author, document class[howto/manual]).
latex_documents = [
  ('index', 'PurePNG.tex', ur'PurePNG Documentation',
   conf['author'], 'manual'),
]

# The name of an image file (relative to this directory) to place at the top of
# the title page.
#latex_logo = None

# http://sphinx.pocoo.org/ext/autodoc.html?highlight=__init__
autoclass_content = 'both'

==> purepng-0.1.3.zip: purepng-0.1.3/man/conf.py <==
# $URL$
# $Rev$

# PyPNG documentation build configuration file, created by
# sphinx-quickstart on Mon Mar 16 13:12:26 2009.
# Then brutally hacked down by drj.
# See http://sphinx.pocoo.org/config.html

import sys, os

# So that local modules get picked up, and picked up first.
sys.path.insert(0, os.path.abspath('../code/png'))
# So that setup.py can be picked up and used for its conf member
sys.path.insert(0, os.path.abspath('..'))

# Expecting to find ../setup.py
from setup import conf

# General configuration
# ---------------------

extensions = ['sphinx.ext.autodoc', 'sphinx.ext.intersphinx']
intersphinx_mapping = {'python': ('https://docs.python.org/2.7', None)}
templates_path = []
source_suffix = '.rst'
master_doc = 'index'
project = 'PurePNG'
copyright = '2016, ' + conf['author']
release = conf['version']
version = release[:release.rfind('.')]
language = 'en'
today_fmt = '%Y-%m-%d'
exclude_trees = ['build']


# Options for HTML output
# -----------------------

html_static_path = []
html_last_updated_fmt = '%Y-%m-%dT%H:%M:%S'
htmlhelp_basename = 'PurePNGdoc'


# Options for LaTeX output
# ------------------------

# The paper size ('letter' or 'a4').
latex_paper_size = 'a4'

# The font size ('10pt', '11pt' or '12pt').
#latex_font_size = '10pt'

#Grouping the document tree into LaTeX files. List of tuples
#(source start file, target name, title, author, document class[howto/manual]).
latex_documents = [
  ('index', 'PurePNG.tex', 'PurePNG Documentation',
   conf['author'], 'manual'),
]

# The name of an image file (relative to this directory) to place at the top of
# the title page.
#latex_logo = None

# http://sphinx.pocoo.org/ext/autodoc.html?highlight=__init__
autoclass_content = 'both'
